@@ -12,6 +12,8 @@ Usage::
         ListFeaturesPaginator,
         ListLaunchesPaginator,
         ListProjectsPaginator,
+        ListSegmentReferencesPaginator,
+        ListSegmentsPaginator,
     )
 
     session = Session()
@@ -21,6 +23,8 @@ Usage::
     list_features_paginator: ListFeaturesPaginator = client.get_paginator("list_features")
     list_launches_paginator: ListLaunchesPaginator = client.get_paginator("list_launches")
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
+    list_segment_references_paginator: ListSegmentReferencesPaginator = client.get_paginator("list_segment_references")
+    list_segments_paginator: ListSegmentsPaginator = client.get_paginator("list_segments")
     ```
 """
 from .client import CloudWatchEvidentlyClient
@@ -29,6 +33,8 @@ from .paginator import (
     ListFeaturesPaginator,
     ListLaunchesPaginator,
     ListProjectsPaginator,
+    ListSegmentReferencesPaginator,
+    ListSegmentsPaginator,
 )
 
 Client = CloudWatchEvidentlyClient
@@ -41,4 +47,6 @@ __all__ = (
     "ListFeaturesPaginator",
     "ListLaunchesPaginator",
     "ListProjectsPaginator",
+    "ListSegmentReferencesPaginator",
+    "ListSegmentsPaginator",
 )
