@@ -64,6 +64,7 @@ from .type_defs import (
     MetricGoalConfigTypeDef,
     MetricMonitorConfigTypeDef,
     OnlineAbConfigTypeDef,
+    ProjectAppConfigResourceConfigTypeDef,
     ProjectDataDeliveryConfigTypeDef,
     PutProjectEventsResponseTypeDef,
     S3DestinationConfigTypeDef,
@@ -217,6 +218,7 @@ class CloudWatchEvidentlyClient(BaseClient):
         self,
         *,
         name: str,
+        appConfigResource: ProjectAppConfigResourceConfigTypeDef = ...,
         dataDelivery: ProjectDataDeliveryConfigTypeDef = ...,
         description: str = ...,
         tags: Mapping[str, str] = ...
@@ -596,7 +598,11 @@ class CloudWatchEvidentlyClient(BaseClient):
         """
 
     def update_project(
-        self, *, project: str, description: str = ...
+        self,
+        *,
+        project: str,
+        appConfigResource: ProjectAppConfigResourceConfigTypeDef = ...,
+        description: str = ...
     ) -> UpdateProjectResponseTypeDef:
         """
         Updates the description of an existing project.
