@@ -49,6 +49,7 @@ __all__ = (
     "OnlineAbConfigTypeDef",
     "TreatmentConfigTypeDef",
     "LaunchGroupConfigTypeDef",
+    "ProjectAppConfigResourceConfigTypeDef",
     "CreateSegmentRequestRequestTypeDef",
     "SegmentTypeDef",
     "DeleteExperimentRequestRequestTypeDef",
@@ -86,6 +87,7 @@ __all__ = (
     "ListTagsForResourceRequestRequestTypeDef",
     "MetricDefinitionConfigTypeDef",
     "MetricDefinitionTypeDef",
+    "ProjectAppConfigResourceTypeDef",
     "S3DestinationConfigTypeDef",
     "S3DestinationTypeDef",
     "PutProjectEventsResultEntryTypeDef",
@@ -97,13 +99,13 @@ __all__ = (
     "TagResourceRequestRequestTypeDef",
     "TestSegmentPatternRequestRequestTypeDef",
     "UntagResourceRequestRequestTypeDef",
-    "UpdateProjectRequestRequestTypeDef",
     "BatchEvaluateFeatureRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "StartExperimentResponseTypeDef",
     "StopExperimentResponseTypeDef",
     "StopLaunchResponseTypeDef",
     "TestSegmentPatternResponseTypeDef",
+    "UpdateProjectRequestRequestTypeDef",
     "CreateSegmentResponseTypeDef",
     "GetSegmentResponseTypeDef",
     "ListSegmentsResponseTypeDef",
@@ -267,6 +269,15 @@ class LaunchGroupConfigTypeDef(
     pass
 
 
+ProjectAppConfigResourceConfigTypeDef = TypedDict(
+    "ProjectAppConfigResourceConfigTypeDef",
+    {
+        "applicationId": str,
+        "environmentId": str,
+    },
+    total=False,
+)
+
 _RequiredCreateSegmentRequestRequestTypeDef = TypedDict(
     "_RequiredCreateSegmentRequestRequestTypeDef",
     {
@@ -797,6 +808,15 @@ MetricDefinitionTypeDef = TypedDict(
     total=False,
 )
 
+ProjectAppConfigResourceTypeDef = TypedDict(
+    "ProjectAppConfigResourceTypeDef",
+    {
+        "applicationId": str,
+        "configurationProfileId": str,
+        "environmentId": str,
+    },
+)
+
 S3DestinationConfigTypeDef = TypedDict(
     "S3DestinationConfigTypeDef",
     {
@@ -921,27 +941,6 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateProjectRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateProjectRequestRequestTypeDef",
-    {
-        "project": str,
-    },
-)
-_OptionalUpdateProjectRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateProjectRequestRequestTypeDef",
-    {
-        "description": str,
-    },
-    total=False,
-)
-
-
-class UpdateProjectRequestRequestTypeDef(
-    _RequiredUpdateProjectRequestRequestTypeDef, _OptionalUpdateProjectRequestRequestTypeDef
-):
-    pass
-
-
 BatchEvaluateFeatureRequestRequestTypeDef = TypedDict(
     "BatchEvaluateFeatureRequestRequestTypeDef",
     {
@@ -990,6 +989,28 @@ TestSegmentPatternResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateProjectRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateProjectRequestRequestTypeDef",
+    {
+        "project": str,
+    },
+)
+_OptionalUpdateProjectRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateProjectRequestRequestTypeDef",
+    {
+        "appConfigResource": ProjectAppConfigResourceConfigTypeDef,
+        "description": str,
+    },
+    total=False,
+)
+
+
+class UpdateProjectRequestRequestTypeDef(
+    _RequiredUpdateProjectRequestRequestTypeDef, _OptionalUpdateProjectRequestRequestTypeDef
+):
+    pass
+
+
 CreateSegmentResponseTypeDef = TypedDict(
     "CreateSegmentResponseTypeDef",
     {
@@ -1586,6 +1607,7 @@ _RequiredCreateProjectRequestRequestTypeDef = TypedDict(
 _OptionalCreateProjectRequestRequestTypeDef = TypedDict(
     "_OptionalCreateProjectRequestRequestTypeDef",
     {
+        "appConfigResource": ProjectAppConfigResourceConfigTypeDef,
         "dataDelivery": ProjectDataDeliveryConfigTypeDef,
         "description": str,
         "tags": Mapping[str, str],
@@ -1615,6 +1637,7 @@ _OptionalProjectTypeDef = TypedDict(
     {
         "activeExperimentCount": int,
         "activeLaunchCount": int,
+        "appConfigResource": ProjectAppConfigResourceTypeDef,
         "dataDelivery": ProjectDataDeliveryTypeDef,
         "description": str,
         "experimentCount": int,
